@@ -6,7 +6,7 @@
 ;; URL: https://github.com/astoff/isearch-mb
 ;; Keywords: matching
 ;; Package-Requires: ((emacs "27.1"))
-;; Version: 0.5
+;; Version: 0.7
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -108,7 +108,7 @@
 (defun isearch-mb--after-change (_beg _end _len)
   "Hook to run from the minibuffer to update the isearch state."
   (let ((string (minibuffer-contents))
-        (inhibit-redisplay t))
+        (cursor-in-echo-area t))
     (with-minibuffer-selected-window
       (setq isearch-string (substring-no-properties string))
       (isearch-update-from-string-properties string)
@@ -181,7 +181,7 @@
 Intended as an advice for isearch commands."
   (if (minibufferp)
       (let ((enable-recursive-minibuffers t)
-            (inhibit-redisplay t))
+            (cursor-in-echo-area t))
         (with-minibuffer-selected-window
           (apply args)))
     (apply args)))
@@ -225,11 +225,6 @@ minibuffer."
                    ;; count, so we need this as a workaround.
                    ((symbol-function #'isearch-message) #'isearch-mb--update-prompt)
                    (minibuffer-default-add-function #'isearch-mb--add-defaults)
-                   ;; We need to set `inhibit-redisplay' at certain points to
-                   ;; avoid flicker.  As a side effect, window-start/end in
-                   ;; `isearch-lazy-highlight-update' will have incorrect values,
-                   ;; so we need to lazy-highlight the whole buffer.
-                   (lazy-highlight-buffer (not (null isearch-lazy-highlight)))
                    (wstart nil))
            (minibuffer-with-setup-hook
                (lambda ()
